diff lisp/progmodes/compile.el @ 105915:d1351c2f9b08

* compilation.txt: Add one more error message for msft (Bug#4100).
author Chong Yidong <cyd@stupidchicken.com>
date Sun, 08 Nov 2009 16:30:19 +0000
parents fd7169a87c28
children 25e1d7e37015
line wrap: on
line diff
--- a/lisp/progmodes/compile.el	Sun Nov 08 15:42:32 2009 +0000
+++ b/lisp/progmodes/compile.el	Sun Nov 08 16:30:19 2009 +0000
@@ -297,9 +297,11 @@
      " in \\([^()\n ]+\\)(\\([0-9]+\\))$" 1 2)
 
     (msft
-     ;; AFAWK, The message may be a "warning", "error", or "fatal error".
-     "^\\([0-9]+>\\)?\\(\\(?:[a-zA-Z]:\\)?[^:(\t\n]+\\)(\\([0-9]+\\)) \
-: \\(?:warnin\\(g\\)\\|[a-z ]+\\) C[0-9]+:" 2 3 nil (4))
+     ;; The message may be a "warning", "error", or "fatal error" with
+     ;; an error code, or "see declaration of" without an error code.
+     "^ *\\([0-9]+>\\)?\\(\\(?:[a-zA-Z]:\\)?[^:(\t\n]+\\)(\\([0-9]+\\)) \
+: \\(?:see declaration\\|\\(?:warnin\\(g\\)\\|[a-z ]+\\) C[0-9]+:\\)"
+     2 3 nil (4))
 
     (omake
      ;; "omake -P" reports "file foo changed"